@@ -240,7 +240,8 @@ Annotation Sets: {n_annotation_sets}""".format(
         annotation_set_id: int = None,
         annotation_format: str = 'json',
         export_coordinates: str = 'pixel',
-        full_path: str = 'true',
+        full_path: bool = True,
+        export_tags: bool = True
     ) -> bytes:
         """
         Export annotations for a given annotation set
@@ -249,8 +250,9 @@ Annotation Sets: {n_annotation_sets}""".format(
             annotation_set_id: annotation set id, by default will be used default_annotation_set
             annotation_format: can be one of ['json', 'coco', 'csv'], default='json'
             export_coordinates: converts output values to percentage or pixels, can be one of ['pixel', 'percent'], default='pixel'
-            full_path: uses full image path (e.g. local path), can be one of ['true', 'false'], default='false'
-
+            full_path: uses full image path (e.g. local path),  it can be one of [True, False], default=True
+            export_tags: exports the tags to a CSV file, it can be one of [True, False], default=True
+            
         Returns:
             annotation file content
         """
@@ -260,6 +262,7 @@ Annotation Sets: {n_annotation_sets}""".format(
                 annotation_format=annotation_format,
                 export_coordinates=export_coordinates,
                 full_path=full_path,
+                export_tags=export_tags
             )
 
         print('ERROR: annotation set not defined')
@@ -270,7 +273,8 @@ Annotation Sets: {n_annotation_sets}""".format(
         annotation_set_id: int = None,
         annotation_format: str = 'json',
         export_coordinates: str = 'pixel',
-        full_path: str = 'true',
+        full_path: bool = True,
+        export_tags: bool = True
     ):
         """
         Exports annotations in given format and save to output file
@@ -279,8 +283,9 @@ Annotation Sets: {n_annotation_sets}""".format(
             output_file: output file to save
             annotation_set_id: annotation set id
             annotation_format: can be one of ['json', 'coco', 'csv'], default='json'
-            full_path: uses full image path (e.g. local path), can be one of ['true', 'false'], default='false'
+            full_path: uses full image path (e.g. local path),  it can be one of [True, False], default=True
             export_coordinates: converts output values to percentage or pixels, can be one of ['pixel', 'percent'], default='pixel'
+            export_tags: exports the tags to a CSV file, it can be one of [True, False], default=True
         """
         annotation_set = self.get_annotation_set(annotation_set_id)
         if annotation_set:
@@ -290,6 +295,7 @@ Annotation Sets: {n_annotation_sets}""".format(
                 annotation_format=annotation_format,
                 full_path=full_path,
                 export_coordinates=export_coordinates,
+                export_tags=export_tags
             )
         else:
             print('ERROR: annotation set not defined')
